==> cramr_ui_lib-1.0.14.tar.gz: lib/widgets/notification_setting_widget.dart <==
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import '../settings/settings_controller.dart';

class NotificationSettingWidget extends StatefulWidget {
  const NotificationSettingWidget(
      {super.key,
      required this.controller,
      required this.isNotificationEnabled,
      required this.selectedTimeOfDay});

  final SettingsController controller;
  final bool isNotificationEnabled;
  final TimeOfDay selectedTimeOfDay;

  @override
  State<NotificationSettingWidget> createState() =>
      NotificationSettingWidgetState();
}

class NotificationSettingWidgetState extends State<NotificationSettingWidget> {
  late bool notificationEnabled;
  late TimeOfDay timeOfDay;

  @override
  void initState() {
    super.initState();
    notificationEnabled = widget.isNotificationEnabled;
    timeOfDay = widget.selectedTimeOfDay;
  }

  @override
  Widget build(BuildContext context) {
    return Card(
        child: Column(
      children: [
        SizedBox(
          height: 70,
          width: 220,
          child: ListTile(
            trailing: Switch(
                value: notificationEnabled,
                onChanged: (bool value) {
                  setState(() {
                    notificationEnabled = value;
                    widget.controller
                        .updateNotificationEnabled(notificationEnabled);
                    if (notificationEnabled) {
                      widget.controller.scheduleDailyHHMMNotification(
                          timeOfDay.hour, timeOfDay.minute);
                    } else {
                      widget.controller.cancelNotifications();
                    }
                  });
                }),
            title: Opacity(
              opacity: notificationEnabled ? 1.0 : .25,
              child: timeDisplay(context),
            ),
          ),
        ),
      ],
    ));
  }

  Widget timeDisplay(BuildContext context) {
    NumberFormat format = NumberFormat('00');
    return InkWell(
      onTap: () {
        if (notificationEnabled) {
          Future<TimeOfDay?> newTimeOfDay = showTimePicker(
              context: context,
              initialTime: timeOfDay,
              builder: (BuildContext context, Widget? child) {
                return MediaQuery(
                  data: MediaQuery.of(context)
                      .copyWith(alwaysUse24HourFormat: true),
                  child: child!,
                );
              },
              initialEntryMode: TimePickerEntryMode.dial);
          newTimeOfDay.then((value) {
            if (value != null) {
              setState(() {
                timeOfDay = value;
                widget.controller.updateNotificationTime(timeOfDay);
              });
            }
          });
        }
      },
      child: Row(
        children: [
          Chip(
            label: Text(format.format(timeOfDay.hour)),
          ),
          const Text(' : '),
          Chip(
            label: Text(format.format(timeOfDay.minute)),
          ),
        ],
      ),
    );
  }
}

==> cramr_ui_lib-1.0.16.tar.gz: lib/widgets/notification_setting_widget.dart <==
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import '../settings/settings_controller.dart';

class NotificationSettingWidget extends StatefulWidget {
  const NotificationSettingWidget(
      {super.key,
      required this.controller,
      required this.isNotificationEnabled,
      required this.selectedTimeOfDay});

  final SettingsController controller;
  final bool isNotificationEnabled;
  final TimeOfDay selectedTimeOfDay;

  @override
  State<NotificationSettingWidget> createState() =>
      NotificationSettingWidgetState();
}

class NotificationSettingWidgetState extends State<NotificationSettingWidget> {
  late bool notificationEnabled;
  late TimeOfDay timeOfDay;

  @override
  void initState() {
    super.initState();
    notificationEnabled = widget.isNotificationEnabled;
    timeOfDay = widget.selectedTimeOfDay;
  }

  @override
  Widget build(BuildContext context) {
    return Card(
        child: Column(
      children: [
        SizedBox(
          height: 70,
          width: 220,
          child: ListTile(
            trailing: Switch(
                value: notificationEnabled,
                onChanged: (bool value) {
                  setState(() {
                    notificationEnabled = value;
                    widget.controller
                        .updateNotificationEnabled(notificationEnabled);
                    if (notificationEnabled) {
                      widget.controller.scheduleNotification(
                          hour: widget.selectedTimeOfDay.hour,
                          minute: widget.selectedTimeOfDay.minute,
                          title: 'Tijd om te oefenen',
                          body: 'Oefen je werkwoorden iedere dag een beetje',
                          payload:
                              'op die manier krijg je het beste resultaat');
                    } else {
                      widget.controller.cancelNotifications();
                    }
                  });
                }),
            title: Opacity(
              opacity: notificationEnabled ? 1.0 : .25,
              child: timeDisplay(context),
            ),
          ),
        ),
      ],
    ));
  }

  Widget timeDisplay(BuildContext context) {
    NumberFormat format = NumberFormat('00');
    return InkWell(
      onTap: () {
        if (notificationEnabled) {
          Future<TimeOfDay?> newTimeOfDay = showTimePicker(
              context: context,
              initialTime: timeOfDay,
              builder: (BuildContext context, Widget? child) {
                return MediaQuery(
                  data: MediaQuery.of(context)
                      .copyWith(alwaysUse24HourFormat: true),
                  child: child!,
                );
              },
              initialEntryMode: TimePickerEntryMode.dial);
          newTimeOfDay.then((value) {
            if (value != null) {
              setState(() {
                timeOfDay = value;
                widget.controller.scheduleNotification(
                    hour: timeOfDay.hour,
                    minute: timeOfDay.minute,
                    title: 'Oefen nu je Franse werkwoorden',
                    body: 'en bouw verder aan je streak!',
                    payload: 'en bouw verder aan je streak!');
              });
            }
          });
        }
      },
      child: Row(
        children: [
          Chip(
            label: Text(format.format(timeOfDay.hour)),
          ),
          const Text(' : '),
          Chip(
            label: Text(format.format(timeOfDay.minute)),
          ),
        ],
      ),
    );
  }
}
